package com.dzeio.openhealth.ui.water

import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.navigation.fragment.findNavController
import androidx.recyclerview.widget.LinearLayoutManager
import com.dzeio.charts.Entry
import com.dzeio.charts.series.BarSerie
import com.dzeio.openhealth.adapters.WaterAdapter
import com.dzeio.openhealth.core.BaseFragment
import com.dzeio.openhealth.databinding.FragmentMainWaterHomeBinding
import com.dzeio.openhealth.utils.ChartUtils
import dagger.hilt.android.AndroidEntryPoint
import java.text.SimpleDateFormat
import java.util.Date
import java.util.Locale

@AndroidEntryPoint
class WaterHomeFragment :
    BaseFragment<WaterHomeViewModel, FragmentMainWaterHomeBinding>(WaterHomeViewModel::class.java) {

    override val bindingInflater: (LayoutInflater, ViewGroup?, Boolean) -> FragmentMainWaterHomeBinding =
        FragmentMainWaterHomeBinding::inflate

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)

        viewModel.init()

        val recycler = binding.list

        val manager = LinearLayoutManager(requireContext())
        recycler.layoutManager = manager

        val adapter = WaterAdapter()
        adapter.onItemClick = {
            findNavController().navigate(
                WaterHomeFragmentDirections.actionNavWaterHomeToNavWaterEdit(
                    it.id
                )
            )
        }
        recycler.adapter = adapter

        val chart = binding.chart

        val serie = BarSerie(chart)

        chart.apply {
            ChartUtils.materielTheme(chart, requireView())

            yAxis.apply {
//                onValueFormat
            }

            xAxis.apply {
                dataWidth = 604800000.0
                textPaint.textSize = 32f
                onValueFormat = onValueFormat@{
                    return@onValueFormat SimpleDateFormat(
                        "yyyy-MM-dd",
                        Locale.getDefault()
                    ).format(Date(it.toLong()))
                }
            }
        }

        binding.buttonEditDefaultIntake.setOnClickListener {
            findNavController().navigate(WaterHomeFragmentDirections.actionNavWaterHomeToNavWaterSizeDialog())
        }


        viewModel.items.observe(viewLifecycleOwner) { list ->
            adapter.set(list)

            val dataset = list.map {
                return@map Entry(
                    it.timestamp.toDouble(),
                    it.value.toFloat()
                )
            }

            serie.entries = dataset as ArrayList<Entry>
            chart.xAxis.x = dataset[0].x
            chart.refresh()
        }
    }
}
